@@ -21,7 +21,6 @@ from .fields import ViewsetModelField
 from .table import Table
 from .chart import MixedChart
 from . import views
-from django.db.models.expressions import Ref
 
 
 ADDITIONAL_LOOKUPS = {
@@ -50,7 +49,6 @@ ADDITIONAL_LOOKUPS = {
 
 
 NUMBER_AGGREGATES = {
-    'count':    Count,
     'avg':      Avg,
     'sum':      Sum,
     'min':      Min,
@@ -59,6 +57,7 @@ NUMBER_AGGREGATES = {
     'stddev':   StdDev,
 }
 
+
 AGGREGATES = {
     IntegerField: NUMBER_AGGREGATES,
     PositiveBigIntegerField: NUMBER_AGGREGATES,
@@ -80,10 +79,19 @@ class HtmxViewSetBase(ABC):
     master          : Optional = None
     base_template   : Optional[str] = 'htmx_viewsets/full.html'
     charts          : Iterable = []
+    permissions = {
+        'list':     ['{app_label}.view_{model_name}'],
+        'detail':   ['{app_label}.view_{model_name}'],
+        'create':   ['{app_label}.add_{model_name}'],
+        'update':   ['{app_label}.change_{model_name}'],
+        'delete':   ['{app_label}.delete_{model_name}'],
+        'table':    ['{app_label}.view_{model_name}'],
+        'chart':    ['{app_label}.view_{model_name}'],
+    }
 
     @classmethod
     def get_urls(cls):  # @NoSelf
-        return [view.url_path for view in cls.get_views()]
+        return ([view.url_path for view in cls.get_views()], cls.namespace)
 
     @classmethod
     def get_url_names(cls):
@@ -97,10 +105,42 @@ class HtmxViewSetBase(ABC):
         return views
 
     @classmethod
-    def get_view(cls, code, view_class):
-        view_kwargs = {'viewset_class': cls}
-        new_view_class = type(view_class.__name__, (view_class,), view_kwargs)
+    def format_permission(cls, perm):
+        kwargs = {
+            'app_label': cls.model._meta.app_label,
+            'model_name': cls.model._meta.model_name,
+        }
+        return perm.format(**kwargs)
 
+    @classmethod
+    def get_permissions(cls, view_class):
+        if isinstance(cls.permissions, dict):
+            perms = cls.permissions[view_class.code]
+        else:
+            perms = cls.permissions
+
+        if isinstance(perms, Iterable):
+            perms = cls.permissions
+        else:
+            perms = [perms]
+
+        return [cls.format_permission(perm) for perm in perms]
+
+    @classmethod
+    def get_view(cls, code, view_class):
+        """
+        We need to load the Permission mixin here to avoid Apps not loaded error
+        """
+        from django.contrib.auth.mixins import PermissionRequiredMixin
+        view_kwargs = {
+            'viewset_class': cls,
+            'permission_required': cls.get_permissions(view_class),
+        }
+        new_view_class = type(
+            view_class.__name__,
+            (view_class, PermissionRequiredMixin),
+            view_kwargs
+        )
         url_path = cls.url_paths[code]
         url_name = cls.url_names[code].split(':')[-1]
         setattr(
@@ -141,7 +181,6 @@ class HtmxModelViewSet(HtmxViewSet):
 
     filter_form_class: Optional[forms.Form] = FilterForm
     add_filter_form_class: Optional[forms.Form] = AddFilterForm
-    #add_filter_form_class: Optional[forms.Form] = AddFilterForm
     remove_filter_form_class: Optional[forms.Form] = RemoveFilterForm
     group_by_form_class: forms.Form = GroupByForm
 
@@ -156,6 +195,7 @@ class HtmxModelViewSet(HtmxViewSet):
     base_queryset: QuerySet
     prefetch_related: Iterable[str] = None
     select_related: Iterable[str] = None
+    aggregate_count_pk = True
 
     def __init__(self, request):
         self.request = request
@@ -180,6 +220,8 @@ class HtmxModelViewSet(HtmxViewSet):
         self.table = self.get_table(qs, self.viewset_fields)
 
     def annotate_aggregates(self, qs):
+        if self.aggregate_count_pk:
+            qs = qs.annotate(Count('pk'))
         for field in qs.query.get_meta().fields:
             aggregates = self.default_aggregates.get(field.__class__, {})
             for name, func in aggregates.items():
@@ -190,10 +232,7 @@ class HtmxModelViewSet(HtmxViewSet):
         viewset_fields = self.get_fields(qs)
         lookups = []
         for field in viewset_fields:
-            field_lookups = field.get_lookups(only_groupable=only_groupable)
-            for name, verbose_name in field_lookups:
-                #bla =  qs.query.get_lookup(f'{field.name}__{name}')
-                lookups.append((f'{field.name}__{name}', verbose_name))
+            lookups += field.get_lookups(only_groupable=only_groupable)
         return lookups
 
     def get_group_by_lookups(self, qs):
@@ -262,13 +301,8 @@ class HtmxModelViewSet(HtmxViewSet):
 
     def get_group_by_fields(self, qs):
         fields = OrderedDict()
-        if qs.query.group_by == True:
-            raise
         for expression in qs.query.group_by:
-            if isinstance(expression, Ref):
-                field = copy(expression.output_field)
-            else:
-                field = copy(expression.source_expressions[0].output_field)
+            field = copy(expression.output_field)
             name = self.group_by_form.cleaned_data['group_by']
             setattr(field, 'name', name)
             fields[name] = self.field_class(field, qs)
@@ -308,18 +342,21 @@ class HtmxModelViewSet(HtmxViewSet):
             self.request, qs, fields, table_id, self.url_names)
 
 
-def modelviewset_factory(model=None, queryset=None, **kwargs):
-    cls = kwargs.get('viewset', HtmxModelViewSet)
+def modelviewset_factory(model=None, queryset=None, permissions=None, **kwargs):
+    cls = kwargs.get('viewset_class', HtmxModelViewSet)
     assert model or isinstance(queryset, QuerySet)
     model = model or queryset.model
     if not isinstance(queryset, QuerySet):
         queryset = model._default_manager.all()
+    perms = permissions if permissions is not None else cls.permissions
     kwargs.update({
         'model': model,
         'base_queryset': queryset,
         'node_id': model._meta.model_name,
-        'namespace': model.__module__.split('.')[0],
+        'permissions': perms,
     })
+    if 'namespace' not in kwargs:
+        kwargs['namespace'] = f'{model._meta.model_name}_viewset'
     kwargs.update(kwargs)
     cls = type(cls.__name__, (cls,), kwargs)
     setattr(cls, 'url_names', cls.get_url_names())
